#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Decimal
version:              0.5.2
visibility:           public
id:                   Decimal-0.5.2-7GheH0MVLCjHIokMpQ8dlu
key:                  Decimal-0.5.2-7GheH0MVLCjHIokMpQ8dlu
license:              BSD-3-Clause
copyright:            Paul Johnson, 2013, 2018, 2021.
maintainer:           paul@cogito.org.uk
author:               Paul Johnson
stability:            beta
homepage:             https://github.com/PaulJohnson/Haskell-Decimal
synopsis:             Decimal numbers with variable precision
description:
    A decimal number has an integer mantissa and a negative
    exponent.  The exponent can be interpreted as the number
    of decimal places in the value.

category:             Math
abi:                  3e706cf017d14d400a7bb9e5bba4b377
exposed:              True
exposed-modules:      Data.Decimal
import-dirs:          /usr/lib/ghc-8.10.5/site-local/Decimal-0.5.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/Decimal-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/Decimal-0.5.2
hs-libraries:         HSDecimal-0.5.2-7GheH0MVLCjHIokMpQ8dlu
depends:              base-4.14.2.0 deepseq-1.4.4.0
haddock-interfaces:   /usr/share/doc/haskell-decimal/html/Decimal.haddock
haddock-html:         /usr/share/doc/haskell-decimal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

